Rename {Switch,Port,Link,Host}Event -> {...}Data

Change-Id: I89d8bae8358409514132eeac00deb0c947ecf68f
diff --git a/src/main/java/net/onrc/onos/core/topology/HostImpl.java b/src/main/java/net/onrc/onos/core/topology/HostImpl.java
index 90af82b..e45e015 100644
--- a/src/main/java/net/onrc/onos/core/topology/HostImpl.java
+++ b/src/main/java/net/onrc/onos/core/topology/HostImpl.java
@@ -35,7 +35,7 @@
     public Iterable<Port> getAttachmentPoints() {
         List<Port> ports = new ArrayList<>();
         final BaseTopologyAdaptor topo = new BaseTopologyAdaptor(topology);
-        for (SwitchPort swp : getHostEvent().getAttachmentPoints()) {
+        for (SwitchPort swp : getHostData().getAttachmentPoints()) {
             Port port = topo.getPort(swp);
             if (port != null) {
                 ports.add(port);
@@ -46,7 +46,7 @@
 
     @Override
     public long getLastSeenTime() {
-        return this.topology.getHostEvent(id).getLastSeenTime();
+        return this.topology.getHostData(id).getLastSeenTime();
     }
 
     @Override
@@ -55,12 +55,12 @@
     }
 
     /**
      * Gets the current HostEvent.
      *
-     * @return HostEvent
+     * @return HostData
      */
-    private HostEvent getHostEvent() {
-        return this.topology.getHostEvent(id);
+    private HostData getHostData() {
+        return this.topology.getHostData(id);
     }
 
     /**
@@ -55,12 +55,12 @@
 
     /**
-     * Gets the current HostEvent.
+     * Gets the current HostData.
      *